from gxkit.dbtools.dbclient import dbclient

try:
    from gxkit_dbtools.client.mysql_client import MySQLClient
    from gxkit_dbtools.client.clickhouse_client import ClickHouseClient
    from gxkit_dbtools.client.iotdb_client import IoTDBClient
    from gxkit_dbtools.parser.sql_parser import SQLParser
except ImportError as e:
    from gxkit.core.loader import try_import_dbtools

    _dbtools = try_import_dbtools()
    MySQLClient = _dbtools.MySQLClient
    ClickHouseClient = _dbtools.ClickHouseClient
    IoTDBClient = _dbtools.IoTDBClient
    SQLParser = _dbtools.SQLParser

__all__ = [
    "MySQLClient",
    "ClickHouseClient",
    "IoTDBClient",
    "dbclient",
    "SQLParser"
]



import importlib
from typing import Any, TYPE_CHECKING
from gxkit.core import __version__

_EXPORTS = {
    "dbclient": "dbtools.dbclient",
}

_SUBMODULES = ["dbtools"]

__all__ = list(_EXPORTS.keys()) + _SUBMODULES

__version__ = __version__


def __getattr__(name: str) -> Any:
    """懒加载所有模块"""
    if name in _EXPORTS:
        module_path = f"gxkit.{_EXPORTS[name]}"
        module = importlib.import_module(module_path, __name__)
        return getattr(module, name)
    if name in _SUBMODULES:
        return importlib.import_module(f".{name}", __name__)
    raise AttributeError(f"module {__name__} has no attribute {name}")


def __dir__():
    """返回IDE可识别的顶层列表"""
    return __all__


if TYPE_CHECKING:
    from gxkit.dbtools.dbclient import dbclient



import importlib


def try_import_module(module_name: str, hint: str = ""):
    try:
        return importlib.import_module(module_name)
    except ImportError as e:
        raise ImportError(
            f"Module [{module_name}] is not installed.\n"
            f"{hint or f'Please install it using: pip install {module_name}'}"
        ) from e


def try_import_dbtools():
    return try_import_module("gxkit_dbtools", "Please install it using: pip install gxkit-dbtools")


def try_import_dataprep():
    return try_import_module("gxkit_dataprep", "Please install it using: pip install gxkit-dataprep")
